@@ -28,7 +28,8 @@ GetExpression <- function(ProteinAccList , directorypath = NULL){
     message("Please connect to the internet as the package requires internect connection.")
     return()
   }
-
+  message("Please wait we are processing your accessions ...")
+  pb <- progress::progress_bar$new(total = length(ProteinAccList))
     # Expression information to be collected
     columns <- c("comment(DEVELOPMENTAL STAGE),comment(INDUCTION),comment(TISSUE SPECIFICITY)")
     baseUrl <- "http://www.uniprot.org/uniprot/"
@@ -70,6 +71,8 @@ GetExpression <- function(ProteinAccList , directorypath = NULL){
     }else {
       HandleBadRequests(Request$status_code)
     }
+      pb$tick()
+      
     }
     if(!is.null(directorypath))
     {
